classdef Solution < handle

    properties
        % quality of classification
        accuracy = '';
        precision = '';
        recall = '';
        f1score = '';
        truePositives = '';
        falsePositives = '';
        trueNegatives = '';
        falseNegatives = '';


        % running times
        cpuGetMean = 0;
        cpuSimSelect = 0;
        cpuSimFunction = 0;
        cpuqFunction = 0;
        cpuAlgorithm = 0;
        cpuClassify = 0;


        % ground truth json
        groundTruthJson = ''

        % functions
        datasetFunc = '';
        seedSelectionFunc = '';
        preProcessFunc = '';
        getDataForSeedSelection = '';
        simSelectFunc = '';
        simFunc = '';
        qFunc = '';
        algFunc = '';

        % dataset parameters
        neuronCover;
        dataFile = [];
        processedData = [];
        ROIs = [];
        datasetSize = [];
        nFrames = -1;
        nFramesEff = -1;
        boundaryWidth = -1;
        dataFileName;

        % window parameters
        windowSize;
        coordinates = [];
        roiNumber = -1;
        effHeight = -1;
        effWidth = -1;

        % seed selection parameters
        seedCondition;
        seedSelectionThreshold;
        selectSeeds;
        posSeeds = [];
        negSeeds = [];
        test = [];
        labels = [];
        assignedLabels = [];
        seedMap;
        fileNameSeeds;
        numNegSeeds;
        pixelNotSegmented;
        simListMean;
        gradientThreshold;

        percentilForSeeds;
        posSeedsSize;
        distNeg;
        maskSize
        maxShift;
        detNegSeeds;

        potentialSeeds;
        potentialSeedIndex;

        bestSegmentation
        bestSegmentationIndex

        % preprocessing parameters
        framesSelect;
        coordinatesPreProcess = [0,0,0,0];

        % simSelect parameters & variables
        idxI = [];
        idxJ = [];

        neighborhoodSize = -1;

        % simFunc variables & parameters
        inBetweenVal = [];
        simVal = [];

        % qFunc variables
        inBetweenSimSource = [];
        alpha = -1;
        beta;

        % algorithm parameters & variables
        lambda = -1;
        lambdas;
        cuts;

        % mean properties
        meanMat = [];

		% sparse computation properties
		gridRes = -1;
        percCols = -1;
        percRows = -1;
		boxes;
		neighborBoxes;
		boxMapping;
		pcaScores;
        pcaCoeff;
        explainedVar;
        nPcaComps = -1;

        % parameters needed for SNC
        simMatrix = [];
        compressSimMatrix = [];
        sourceWeights = [];
        sinkWeights = [];
        precomputedSum = [];
        nTest = -1;

        % final results
        segmentations;
        numCells = 0;

        % average neuron size
        averageNeuronSize;
        maxNeuronPixels;
        minNeuronPixels;
        fileNameBase;

        % memmapped file
        mm;
        data;

        percSampleCorrspace;
    end
    methods
        function obj = Solution( hparams)
            % Setup configuration options
            obj.fileNameBase = ['./HNCcorrResults/' hparams.fileNameBase];
            obj.dataFileName = hparams.dataFileName;
            obj.groundTruthJson = hparams.jsonFile;

            obj.boundaryWidth = hparams.boundaryWidth;
            obj.datasetSize = hparams.dataSize;
            obj.nFramesEff = hparams.nFrames;
            obj.windowSize = hparams.windowSize;
            obj.segmentations = {};
            obj.numCells = 0;
            obj.seedCondition = true;
            obj.roiNumber = 0;
            obj.minNeuronPixels = hparams.minSize;
            obj.averageNeuronSize = hparams.avgSize;
            obj.maxNeuronPixels = hparams.maxSize;
            obj.getDataForSeedSelection = @(varargin) getRawData(obj,varargin);
            %this.ROIs = jsonToROIsConverter( this.datasetAbbr, this.datasetSize );

            obj.mm = memmapfile(obj.dataFileName, 'Format', {'double', [obj.datasetSize(1), obj.datasetSize(2), obj.nFramesEff], 'x'});
            obj.data = obj.mm.Data.x;

            obj.percSampleCorrspace = hparams.percSampleCorrspace;

            if not( strcmp( obj.groundTruthJson,'') )
                obj.ROIs = jsonToROIsConverter( jsonFile, obj.datasetSize, windowSize );
            end

            if ~isempty(obj.ROIs)
                obj.neuronCover = computeNeuronCover( obj );
            end

            % Seed Selection Setup
            obj.distNeg = hparams.distNeg;
            obj.numNegSeeds = hparams.numNegSeeds;
            obj.maxShift = hparams.maxShift;
            obj.maskSize = hparams.maskSize; %Configurable parameter or fixed one?
            obj.posSeedsSize = hparams.posSeedSize;
            obj.percentilForSeeds = hparams.percSeeds;
            obj.detNegSeeds = hparams.detNegSeeds;
            obj.selectSeeds = @(x) fiveByFiveAllPixels( obj, obj.distNeg );
            %this.spikes = containers.Map;

            % Preprocessing function setup to correlation space
            obj.preProcessFunc = @(varargin) preprocessCorrelation(obj,varargin);

            % Similarity selection function setup to sparse computation
            % with default values
            obj.simSelectFunc = @(void) sparseComputation( obj );
            obj.gridRes = hparams.gridRes;
            obj.nPcaComps = hparams.nPcaComps;
            obj.percRows = hparams.percRows;
            obj.percCols = hparams.percCols;

            %Similarity function setup to Euclidian distance
            obj.simFunc = @( idxI, idxJ, recomputeFlag, duplicate ) computeNormSim2( obj, idxI, idxJ, recomputeFlag , duplicate );

            %Similarity Q function setup to sumTimesSource
            obj.qFunc = @( recomputeSimFlag ) sumOutQ( obj );

            %Algorithm changed to Normalized cut
            obj.algFunc = @( x ) SNC( obj );
        end

        function changeWindow( this, varargin )
            % check if ID or window specification is given
            this.roiNumber = varargin{1};

            %coordinates are assigned in dataSeedSelection, This
            %coordinates come from the last execution of dataSeedSelection.
            this.effWidth = this.coordinates( 4 ) - this.coordinates( 3 ) + 1 + 2 * this.boundaryWidth;
            this.effHeight = this.coordinates( 2 ) - this.coordinates( 1 ) + 1 + 2 * this.boundaryWidth;

            if this.boundaryWidth == 0
                this.dataFile = this.data(this.coordinates(1) : this.coordinates(2), this.coordinates(3) : this.coordinates(4), :);
            else
                this.dataFile = zeros( this.effHeight, this.effWidth, this.nFramesEff );
                this.dataFile( this.boundaryWidth + 1 : end - this.boundaryWidth, this.boundaryWidth + 1 : end - this.boundaryWidth, : ) = this.data(this.coordinates(1) : this.coordinates(2), this.coordinates(3) : this.coordinates(4), :);
            end
            this.datasetFunc = @(x) this.dataFile;
        end

        function saveSeedSelectionPlots( this )
            h = figure('visible','off');
            imagesc(reshape(this.simListMean,this.datasetSize(1),this.datasetSize(2)));
            fileName = [ 'seedSelectionPlots/simListMean-' this.fileNameBase '.pdf'];
            saveas(gcf,fileName,'pdf');
        end
    end
end
